Stan Math Library: stan/math/fwd/scal/fun/log_falling_factorial.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log_falling_factorial.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_LOG_FALLING_FACTORIAL_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_LOG_FALLING_FACTORIAL_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/log_falling_factorial.hpp>
7 #include <boost/math/special_functions/digamma.hpp>
8
9 namespace stan {
10
11 namespace math {
12
13 template<typename T>
14 inline fvar<T>
15 log_falling_factorial(const fvar<T>& x, const fvar<T>& n) {
16 using stan::math::log_falling_factorial;
17 using boost::math::digamma;
18
19 return fvar<T>(log_falling_factorial(x.val_, n.val_),
20 (digamma(x.val_ + 1)
21 - digamma(x.val_ - n.val_ + 1)) * x.d_
22 + digamma(x.val_ - n.val_ + 1) * n.d_);
23 }
24
25 template<typename T>
26 inline fvar<T>
27 log_falling_factorial(const double x, const fvar<T>& n) {
28 using stan::math::log_falling_factorial;
29 using boost::math::digamma;
30
31 return fvar<T>(log_falling_factorial(x, n.val_),
32 digamma(x - n.val_ + 1) * n.d_);
33 }
34
35 template<typename T>
36 inline fvar<T>
37 log_falling_factorial(const fvar<T>& x, const double n) {
38 using stan::math::log_falling_factorial;
39 using boost::math::digamma;
40
41 return fvar<T>(log_falling_factorial(x.val_, n),
42 (digamma(x.val_ + 1)
43 - digamma(x.val_ - n + 1)) * x.d_);
44 }
45 }
46 }
47 #endif
core.hpp
stan::math::log_falling_factorial
fvar< T > log_falling_factorial(const fvar< T > &x, const fvar< T > &n)
Definition: log_falling_factorial.hpp:15
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
log_falling_factorial.hpp
stan::math::fvar
Definition: fvar.hpp:13
stan::math::digamma
fvar< T > digamma(const fvar< T > &x)
Definition: digamma.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.